@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: loop.c,v 1.4 2004/03/13 16:51:01 d Exp $ */
+/* $Id: loop.c,v 1.5 2004/05/24 10:38:46 d Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -25,7 +25,7 @@ loop_tag(p, end)
 	memcpy(&af, p, sizeof af);
 	p += sizeof af;
 
-	switch (af) {
+	switch (ntohl(af)) {
 	case AF_INET:
 		return ip_tag(p, end);
 	case AF_INET6:
